%  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----
% "Sperm gatekeeping: 3D imaging reveals 
% a constricted entrance to zebra finch sperm storage tubules "
%
% Authors: Tania Mendonca, Ashley J Cadby and Nicola Hemmings
% 
% Contact: Tania.Mendonca@nottingham.ac.uk
%
% -----------------------
%  (3) Measure
% -----------------------

%Import data
Folder = uigetdir; 

[upperPath, deepestFolder,ext] = fileparts(Folder);
  
fileName = horzcat('*','.mat');                %define generic file pattern
filePattern = fullfile(Folder,fileName);  
dataFiles = dir(filePattern); 

for k = 1:length(dataFiles)
    baseFileName = dataFiles(k).name;          %returns current filename
    filedr = fullfile(Folder, baseFileName);

    load(filedr);
    
    imagesc(slice);

% Rescale to match instrument pxl ratio [0.234 0.234 0.75]
X = subX * 0.234;
Y = subY * 0.234;
Z = subZ * 0.750;

slize = size(slice);

% select points along lumen
h = imgcf;
[x,y] = getpts(h);                                % select four points (double click on 4th)
i = sub2ind(slize,round(x),round(y));             % index of points

% coordinates of points from 3d image matrix
a1 = [X(i), Y(i), Z(i)];

% horizontal diameter 
d1 = sqrt((a1(1)-a1(2))^2 + (a1(1,2)-a1(2,2))^2 + (a1(1,3)-a1(2,3))^2);       

% vertical diameter
d2 = sqrt((a1(3)-a1(4))^2 + (a1(3,2)-a1(4,2))^2 + (a1(3,3)-a1(4,3))^2); 

% write to excel
if exist('T','var');
   Tnew=table(kk,d1,d2,l);
   T = [T;Tnew];
else 
       T=table(kk,d1,d2,l);
end

end

xlname=strcat('measurements','.xlsx'); 
T2=table2cell(T);
T3=vertcat(T.Properties.VariableNames,T2);
xlswrite(xlname,T3);
