%  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----
% "Sperm gatekeeping: 3D imaging reveals 
% a constricted entrance to zebra finch sperm storage tubules "
%
% Authors: Tania Mendonca, Ashley J Cadby and Nicola Hemmings
% 
% Contact: Tania.Mendonca@nottingham.ac.uk
%
% -----------------------
%  (2) Slice
% -----------------------

global data p pt pscaled



idx = dsearchn(p,pt);       % Find nearest point to p(path) on pt(interpolated points)
c = length(idx);


for kk = 1:2:c             % For every 2nd interpolated point, find neighbours 
   a = idx(kk);            % on spline.
   p1 = p(a,:);
   
    if kk < 2;             
        p0 = p(a,:);
        p2 = p(a+5,:);
    elseif kk > c-2;
        p0 = p(a-5,:);
        p2 = p(a,:);
    else
        p0 = p(a-5,:);
        p2 = p(a+5,:);
    end
    
  % Create a vector that originates from p0 and extends to p2
  n1 = p2-p1; 
  n2 = cross(p2-p1,p2-p0);                 
  
  [slice1, sliceInd1,subX1, subY1, subZ1] = extractSlice(data,p1(1),...
      p1(2),p1(3),n1(1),n1(2),n1(3),500);        
  [slice2, sliceInd2,subX2, subY2, subZ2] = extractSlice(data,p1(1),...
      p1(2),p1(3),n2(1),n2(2),n2(3),500);                                                                                                           
  
  % distance of slice from opening
  pcurve = pscaled(1:a,:);           % Spline segment from opening to slice 

  if kk == 1;
      l = 0;                         % distance at opening set to zero
  else
      l = arclength(pcurve(:,1),pcurve(:,2),pcurve(:,3));
  end
  
  % Write slice to file
  s = num2str(kk);
  filename = horzcat(s,'.mat');
  save(filename, 'kk', 'slice1', 'slice2', 'sliceInd1',...
      'subX1', 'subY1', 'subZ1','sliceInd2', 'subX2',...
      'subY2', 'subZ2', 'l');
    
end


