%  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----  ~~~~~-----
% "Sperm gatekeeping: 3D imaging reveals 
% a constricted entrance to zebra finch sperm storage tubules "
%
% Authors: Tania Mendonca, Ashley J Cadby and Nicola Hemmings
% 
% Contact: Tania.Mendonca@nottingham.ac.uk
%
% -----------------------
%  (1) Main script
% -----------------------

global data p pt pscaled

% Import SST rendered path data
[file,path] = uigetfile('*.csv','select file','Multiselect','on');
filedr1 = [path,file{1}];

if(isempty(file))
    return
end

p1 = csvread(filedr);
 
% Interpolate the trace spline

lp1 = length(p1);                                                
t1 = linspace(1,lp1,100);                 % 100 pt vector of spline indices
t11 = (1:lp1);                            % spline indices 
x1 = interp1(t11,p1(:,1),t1,'spline');    % interpolate each axes separately 
y1 = interp1(t11,p1(:,2),t1,'spline');    % using the interpolated spline indices
z1 = interp1(t11,p1(:,3),t1,'spline');

x1 = x1(:);
y1 = y1(:);
z1 = z1(:);

pscaled = [x1,y1,z1];

% Scale to match image data pxl ratio
p = [pscaled(:,1)/0.234,pscaled(:,2)/0.234,pscaled(:,3)/0.75];   

% Interpolate the trace spline again for 10 sampling points
lp = length(p);
t = linspace(1,lp,20);
t0 = (1:lp);
x = interp1(t0,p(:,1),t,'spline');
y = interp1(t0,p(:,2),t,'spline');
z = interp1(t0,p(:,3),t,'spline');

x = x(:);
y = y(:);
z = z(:);

pt = [x,y,z];
    
% figure;                                                       
% plot3(p(:,1),p(:,2),p(:,3),'Linewidth',2);
% hold on
% plot3(pt(:,1),pt(:,2),pt(:,3),'rx');

%% Import SST image data
[file2,path2] = uigetfile('*.tif','select file');
filedr2 = [path2,file2];

if(isempty(file2))
    return
end

% get number of images in the .tif stack
info = imfinfo([path2 file2]);
nimages = numel(info);                                          

% import image into matrix
 for I = 1:nimages
 data(:,:,I) = imresize(double(imread(filedr2,I)),1);      
 end


%% Call slice script
SST_spline_slice